@@ -1,17 +1,15 @@
-from airzone.utils import *
-from array import array
-from threading import Lock
-import serial
 import logging
+from threading import Lock
 
-from pymodbus.client.sync import ModbusTcpClient as ModbusClient
+from airzone.utils import *
+from pymodbus.client.sync import ModbusTcpClient as ModbusClient  # type: ignore
 
 
 def state_value(state, address, init=0, end=15):
-    '''
+    """
     init and end are included on the desired slice
-    '''
-    if state == None:
+    """
+    if state is None:
         return 0
     binary = format(state[address], '016b')
     r_init = len(binary)-1-init
@@ -21,7 +19,7 @@ def state_value(state, address, init=0, end=15):
 
 
 def bit_value(state, address, bit):
-    if state == None:
+    if state is None:
         return 0
     # return state_value(state, address, bit, bit)
     temp = format(state[address], '016b')
